qustop.Positive
===============

.. currentmodule:: qustop

.. autoclass:: Positive

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Positive.__init__
      ~Positive.dual_problem
      ~Positive.primal_problem
      ~Positive.solve
   
   

   
   
   